@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import absolute_import
-
 import fnmatch
 
 from cliff import sphinxext
@@ -38,3 +36,4 @@ def setup(app):
     app.add_directive('autodoc-gnocchi', GnocchiAutoDocDirective)
     app.add_config_value('autoprogram_cliff_application', 'gnocchi', True)
     app.add_config_value('autoprogram_cliff_ignored', ['--help'], True)
+    app.add_config_value('autoprogram_cliff_app_dist_name', None, True)
