@@ -20,14 +20,18 @@ import warnings
 
 from cliff import app
 from cliff import commandmanager
+
+from keystoneauth1 import adapter
 from keystoneauth1 import exceptions
 from keystoneauth1 import loading
 
+from gnocchiclient import auth
 from gnocchiclient import benchmark
 from gnocchiclient import client
-from gnocchiclient import noauth
+from gnocchiclient.v1 import aggregates_cli
 from gnocchiclient.v1 import archive_policy_cli
 from gnocchiclient.v1 import archive_policy_rule_cli as ap_rule_cli
+from gnocchiclient.v1 import build_cli
 from gnocchiclient.v1 import capabilities_cli
 from gnocchiclient.v1 import metric_cli
 from gnocchiclient.v1 import resource_cli
@@ -39,6 +43,7 @@ from gnocchiclient.version import __version__
 class GnocchiCommandManager(commandmanager.CommandManager):
     SHELL_COMMANDS = {
         "status": status_cli.CliStatusShow,
+        "server version": build_cli.CliBuildShow,
         "resource list": resource_cli.CliResourceList,
         "resource show": resource_cli.CliResourceShow,
         "resource history": resource_cli.CliResourceHistory,
@@ -46,8 +51,10 @@ class GnocchiCommandManager(commandmanager.CommandManager):
         "resource create": resource_cli.CliResourceCreate,
         "resource update": resource_cli.CliResourceUpdate,
         "resource delete": resource_cli.CliResourceDelete,
+        "resource batch delete": resource_cli.CliResourceBatchDelete,
         "resource-type list": resource_type_cli.CliResourceTypeList,
         "resource-type create": resource_type_cli.CliResourceTypeCreate,
+        "resource-type update": resource_type_cli.CliResourceTypeUpdate,
         "resource-type show": resource_type_cli.CliResourceTypeShow,
         "resource-type delete": resource_type_cli.CliResourceTypeDelete,
         "archive-policy list": archive_policy_cli.CliArchivePolicyList,
@@ -58,6 +65,7 @@ class GnocchiCommandManager(commandmanager.CommandManager):
         "archive-policy-rule list": ap_rule_cli.CliArchivePolicyRuleList,
         "archive-policy-rule show": ap_rule_cli.CliArchivePolicyRuleShow,
         "archive-policy-rule create": ap_rule_cli.CliArchivePolicyRuleCreate,
+        "archive-policy-rule update": ap_rule_cli.CliArchivePolicyRuleUpdate,
         "archive-policy-rule delete": ap_rule_cli.CliArchivePolicyRuleDelete,
         "metric list": metric_cli.CliMetricList,
         "metric show": metric_cli.CliMetricShow,
@@ -69,6 +77,7 @@ class GnocchiCommandManager(commandmanager.CommandManager):
         "measures batch-resources-metrics":
             metric_cli.CliResourcesMetricsMeasuresBatch,
         "measures aggregation": metric_cli.CliMeasuresAggregation,
+        "aggregates": aggregates_cli.CliAggregates,
         "capabilities list": capabilities_cli.CliCapabilitiesList,
         "benchmark metric create": benchmark.CliBenchmarkMetricCreate,
         "benchmark metric show": benchmark.CliBenchmarkMetricShow,
@@ -85,11 +94,10 @@ class GnocchiShell(app.App):
     def __init__(self):
         super(GnocchiShell, self).__init__(
             description='Gnocchi command line client',
-            # FIXME(sileht): get version from pbr
             version=__version__,
-            command_manager=GnocchiCommandManager(None),
+            command_manager=GnocchiCommandManager('gnocchiclient'),
             deferred_help=True,
-            )
+        )
 
         self._client = None
 
@@ -108,35 +116,36 @@ class GnocchiShell(app.App):
             description,
             version,
             argparse_kwargs={'allow_abbrev': False})
-        # Global arguments, one day this should go to keystoneauth1
-        parser.add_argument(
-            '--os-region-name',
-            metavar='<auth-region-name>',
-            dest='region_name',
-            default=os.environ.get('OS_REGION_NAME'),
-            help='Authentication region name (Env: OS_REGION_NAME)')
-        parser.add_argument(
-            '--os-interface',
-            metavar='<interface>',
-            dest='interface',
-            choices=['admin', 'public', 'internal'],
-            default=os.environ.get('OS_INTERFACE'),
-            help='Select an interface type.'
-                 ' Valid interface types: [admin, public, internal].'
-                 ' (Env: OS_INTERFACE)')
         parser.add_argument(
             '--gnocchi-api-version',
             default=os.environ.get('GNOCCHI_API_VERSION', '1'),
             help='Defaults to env[GNOCCHI_API_VERSION] or 1.')
+
+        # NOTE(jd) This is a workaroun for people using Keystone auth with the
+        # CLI. A lot of rc files do not export OS_AUTH_TYPE=password and
+        # assumes it is the default. It's not in that case, but since we can't
+        # fix all the rc files of the world, workaround it here.
+        if ("OS_PASSWORD" in os.environ and
+                "OS_AUTH_TYPE" not in os.environ):
+            os.environ["OS_AUTH_TYPE"] = "password"
+
         loading.register_session_argparse_arguments(parser=parser)
         plugin = loading.register_auth_argparse_arguments(
-            parser=parser, argv=sys.argv, default="password")
+            parser=parser, argv=sys.argv, default="gnocchi-basic")
+
+        if not isinstance(plugin, (auth.GnocchiNoAuthLoader,
+                                   auth.GnocchiBasicLoader)):
+            adapter.register_adapter_argparse_arguments(
+                parser=parser, service_type="metric")
+            adapter.register_service_adapter_argparse_arguments(
+                parser=parser, service_type="metric")
 
-        if not isinstance(plugin, noauth.GnocchiNoAuthLoader):
             parser.add_argument(
                 '--endpoint',
                 default=os.environ.get('GNOCCHI_ENDPOINT'),
-                help='Gnocchi endpoint (Env: GNOCCHI_ENDPOINT)')
+                help='Gnocchi endpoint (Env: GNOCCHI_ENDPOINT). '
+                'Deprecated, use --os-endpoint-override and '
+                'OS_ENDPOINT_OVERRIDE instead')
 
         return parser
 
@@ -145,30 +154,55 @@ class GnocchiShell(app.App):
         # NOTE(sileht): we lazy load the client to not
         # load/connect auth stuffs
         if self._client is None:
-            if hasattr(self.options, "endpoint"):
-                endpoint_override = self.options.endpoint
-            else:
-                endpoint_override = None
             auth_plugin = loading.load_auth_from_argparse_arguments(
                 self.options)
             session = loading.load_session_from_argparse_arguments(
                 self.options, auth=auth_plugin)
 
-            self._client = client.Client(self.options.gnocchi_api_version,
-                                         session=session,
-                                         interface=self.options.interface,
-                                         region_name=self.options.region_name,
-                                         endpoint_override=endpoint_override)
+            if isinstance(auth_plugin, (auth.GnocchiNoAuthPlugin,
+                                        auth.GnocchiBasicPlugin)):
+                # Normal endpoint
+                kwargs = dict(
+                    version=self.options.gnocchi_api_version,
+                    session=session,
+                )
+            else:
+                # Openstck style endpoint
+                kwargs = dict(
+                    version=(self.options.os_metric_api_version or
+                             self.options.os_api_version or
+                             self.options.gnocchi_api_version),
+                    session=session,
+                    adapter_options=dict(
+                        service_type=(self.options.os_metric_service_type or
+                                      self.options.os_service_type),
+                        service_name=(self.options.os_metric_service_name or
+                                      self.options.os_service_name),
+                        interface=(self.options.os_metric_interface or
+                                   self.options.os_interface),
+                        region_name=self.options.os_region_name,
+                        endpoint_override=(
+                            self.options.os_metric_endpoint_override or
+                            self.options.os_endpoint_override or
+                            self.options.endpoint),
+                    )
+                )
+            self._client = client.Client(**kwargs)
         return self._client
 
     def clean_up(self, cmd, result, err):
         if err and isinstance(err, exceptions.HttpError):
             try:
                 error = err.response.json()
-            except Exception:
+            except Exception:  # noqa
                 pass
             else:
-                print(error['description'])
+                if 'description' in error:
+                    # Gnocchi format
+                    print(error['description'])
+                elif 'error' in error and 'message' in error['error']:
+                    # Keystone format
+                    print(error['error']['message'])
 
     def configure_logging(self):
         if self.options.debug:
