@@ -13,9 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import keystoneauth1.session
+
 from gnocchiclient import client
+from gnocchiclient.v1 import aggregates
 from gnocchiclient.v1 import archive_policy
 from gnocchiclient.v1 import archive_policy_rule
+from gnocchiclient.v1 import build
 from gnocchiclient.v1 import capabilities
 from gnocchiclient.v1 import metric
 from gnocchiclient.v1 import resource
@@ -23,22 +27,41 @@ from gnocchiclient.v1 import resource_type
 from gnocchiclient.v1 import status
 
 
-class Client(object):
+class Client:
     """Client for the Gnocchi v1 API.
 
-    :param string session: session
-    :type session: :py:class:`keystoneauth.adapter.Adapter`
+    :param session: keystoneauth1 session
+    :type session: py:class:`keystoneauth1.session.Session` (optional)
+    :param adapter_options: options to pass to
+                            py:class:`keystoneauth1.adapter.Adapter`
+    :type adapter_options: dict (optional)
+    :param session_options: options to pass to
+                            py:class:`keystoneauth1.session.Session`
+    :type session_options: dict (optional)
     """
 
-    def __init__(self, session=None, service_type='metric', **kwargs):
+    def __init__(self, session=None, adapter_options=None,
+                 session_options=None):
         """Initialize a new client for the Gnocchi v1 API."""
-        self.api = client.SessionClient(session, service_type=service_type,
-                                        **kwargs)
+        session_options = session_options or {}
+        adapter_options = adapter_options or {}
+
+        adapter_options.setdefault('service_type', "metric")
+
+        if session is None:
+            session = keystoneauth1.session.Session(**session_options)
+        else:
+            if session_options:
+                raise ValueError("session and session_options are exclusive")
+
+        self.api = client.SessionClient(session, **adapter_options)
         self.resource = resource.ResourceManager(self)
         self.resource_type = resource_type.ResourceTypeManager(self)
         self.archive_policy = archive_policy.ArchivePolicyManager(self)
         self.archive_policy_rule = (
             archive_policy_rule.ArchivePolicyRuleManager(self))
         self.metric = metric.MetricManager(self)
+        self.aggregates = aggregates.AggregatesManager(self)
         self.capabilities = capabilities.CapabilitiesManager(self)
         self.status = status.StatusManager(self)
+        self.build = build.BuildManager(self)
